import { BootstrappedImplementationConfiguration } from '@webprovisions/bootstrapping';
import { ConfigurationApiDefinition, Environment, WidgetSelector } from '@webprovisions/platform';
export interface HumanyConfiguration {
    /**
     * Extensions for the configuration API (optional).
     */
    configurationApiExtensions?: ConfigurationApiDefinition[];
}
/**
 * TODO: this is just here as we dont want to import from ace-knowledge-widgets
 */
export declare const _bootstrap: (implementation: any, configure: any, options?: any) => Promise<any>;
/**
 * The Humany widget runtime.
 */
export default class Humany extends Environment {
    /**
     * Version of the Humany runtime.
     */
    static version: string;
    constructor(name: string, configurationApiExtensions?: ConfigurationApiDefinition[]);
    createImplementation(configuration: BootstrappedImplementationConfiguration): any;
    /**
     * Performs navigation for widgets matching the specified selector by invoking a
     * 'navigate' command.
     * @param selector Widget selector matching the widget(s) to perform navigation on.
     * @param route Route name.
     * @param params Route params.
     */
    navigate(selector: WidgetSelector, route: string, params: {
        [key: string]: string;
    }): void;
    /**
     * Creates a `Humany` runtime based on provided configuration.
     * @param configuration Runtime configuration.
     */
    static create(configuration?: HumanyConfiguration): Humany;
    /**
     * Creates a `Humany` runtime based on provided configuration and retains configuration handlers
     * registered on global context. Use this factory to fully support the default embed script.
     * Will return any existing `Humany` runtime if available.
     * @param configuration Runtime configuration.
     * @param global Object to read configuration handlers from (default: window).
     */
    static createFromGlobal(globalHumany: any, configuration?: HumanyConfiguration): Humany;
    /**
     * Determines whether the specified object is a valid `Humany` runtime.
     * @param obj Object to compare.
     */
    static isRuntime(obj: any): boolean;
}
